"use strict";
///<reference lib="es2015.core"/>
Object.defineProperty(exports, "__esModule", { value: true });
var COMPRESS_PREFIX = /*#__PURE__*/ "?basic=";
/**
 * 获取文件后缀
 * @param path 文件名
 */
function isGif(path) {
    return path && path.toLowerCase().endsWith(".gif");
}
exports.isGif = isGif;
/**
 * URL预处理
 */
function replaceUrl(url, domainList, cdnSite) {
    if (typeof url !== "string") {
        console.error("invalid url<not string>:", url);
    }
    else {
        url = url.split(COMPRESS_PREFIX)[0];
        domainList.forEach(function (e) { return (url = url.replace(e, cdnSite)); });
    }
    return url;
}
/**
 * 配置信息
 */
var Config = /** @class */ (function () {
    function Config() {
        var _this = this;
        /**
         * 宽度
         */
        this.Width = 768;
        /**
         * 屏幕高度
         */
        this.Height = 1024;
        /**
         * 图片质量1~100
         */
        this.Quality = 100;
        /**
         * 缩略图宽度
         */
        this.ThumbnailWidth = 138;
        /**
         * 缩略图宽度1~100
         */
        this.ThumbnailQuality = 1;
        /**
         * 代替换的域名列表
         */
        this.DomainList = [];
        /**
         * 图片处理CDN
         */
        this.ImageCDN = "";
        /**
         * 媒体流加速CDN
         */
        this.StreamCDN = "";
        this.isAndroid = false;
        //@ts-ignore
        if (typeof wx === "object" && wx.getSystemInfo) {
            wx.getSystemInfo({
                success: function (res) {
                    //@ts-ignore
                    _this.isAndroid = res.platform !== "ios";
                    _this.Width = Math.round((res.windowWidth || res.screenWidth) * res.pixelRatio) || _this.Width;
                    if (_this.Width > 4096) {
                        _this.Width = 4096;
                    }
                    _this.Height = Math.round((res.screenHeight || res.windowWidth) * res.pixelRatio) || _this.Height;
                    if (_this.Width > 4096) {
                        _this.Width = 4096;
                    }
                },
            });
        }
    }
    return Config;
}());
exports.config = new Config();
/**
 * 生成压缩URL
 * @param option 压缩参数
 * @param cdnSite CDN域名 如 `https://mycdn.net/` 空则不替换
 * @param domainList 域名列表 `[/^https?:\/\/[\w\-\.]*\//]`
 */
function compress(option, cdnSite, domainList) {
    if (domainList === void 0) { domainList = [/^https?:\/\/[\w\-\.]*\//]; }
    var url = cdnSite ? replaceUrl(option.url, domainList, cdnSite) : cdnSite;
    // //gif图不处理
    // if (ext === "gif") {
    //     return url;
    // }
    var param = "";
    if (option.width) {
        param += "_" + option.width + "w";
    }
    if (option.height) {
        param += "_" + option.height + "h";
    }
    if (option.quality && option.quality < 100) {
        param += "_" + option.quality + "q";
    }
    if (option.progressive) {
        param += "_1pr";
    }
    if (option.scaleType) {
        param += "_" + option.scaleType + "e";
    }
    if (option.cut) {
        param += "_1c";
    }
    if (option.ext) {
        param += option.ext;
    }
    return param ? url + COMPRESS_PREFIX + (option.handleiflarger ? "1l" : "0l") + param : url;
}
exports.compress = compress;
/**
 * 屏幕宽度自适应图像
 * @param url url of image
 */
function adaptiveImage(url) {
    return compress({
        url: url,
        width: exports.config.Width,
        quality: exports.config.Quality,
        progressive: exports.config.Width > 800,
        ext: isGif(url) ? ".gif" : exports.config.isAndroid ? ".webp" : ".jpg",
    }, exports.config.ImageCDN, exports.config.DomainList);
}
exports.adaptiveImage = adaptiveImage;
/**
 * 横屏自适应图像
 * @param url url of image
 */
function adaptiveLandscapeImage(url) {
    var width = exports.config.Width > exports.config.Height ? exports.config.Width : exports.config.Height;
    return isGif(url)
        ? url // gif 不处理
        : compress({
            url: url,
            width: width,
            quality: exports.config.Quality,
            progressive: width > 800,
            ext: exports.config.isAndroid ? ".webp" : ".jpg",
        }, exports.config.ImageCDN, exports.config.DomainList);
}
exports.adaptiveLandscapeImage = adaptiveLandscapeImage;
/**
 * 渐进式加载大图
 * @param url image URL
 */
function progressiveImage(url) {
    return isGif(url)
        ? url // gif 不处理
        : compress({
            url: url,
            progressive: true,
            ext: exports.config.isAndroid ? ".webp" : ".jpg",
        }, exports.config.ImageCDN, exports.config.DomainList);
}
exports.progressiveImage = progressiveImage;
/**
 * 生成好友对话消息的缩略图
 * @param url image Url
 */
function shareImage(url) {
    return compress({
        url: url,
        width: 500,
        height: 400,
        cut: true,
        scaleType: 1,
        quality: 75,
        ext: ".jpg",
    }, exports.config.ImageCDN, exports.config.DomainList);
}
exports.shareImage = shareImage;
/**
 * 小尺寸缩略图
 * @param url 原url
 */
function thumbnail(url) {
    return compress({
        url: url,
        width: exports.config.ThumbnailWidth,
        quality: exports.config.ThumbnailQuality,
        ext: ".jpg",
    }, exports.config.ImageCDN, exports.config.DomainList);
}
exports.thumbnail = thumbnail;
/**
 * 流媒体
 * @param url 原url
 */
function streamCdn(url) {
    return exports.config.StreamCDN ? replaceUrl(url, exports.config.DomainList, exports.config.StreamCDN) : url;
}
exports.streamCdn = streamCdn;
